# Copyright 2018 Markus Scheidgen
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an"AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nomad.cli import lazy_import

lazy_import.lazy_module('sys')
lazy_import.lazy_module('os')
lazy_import.lazy_module('io')
lazy_import.lazy_module('re')
lazy_import.lazy_module('shutil')
lazy_import.lazy_module('requests')
lazy_import.lazy_module('click')
lazy_import.lazy_module('typing')
lazy_import.lazy_module('datetime')
lazy_import.lazy_module('subprocess')
lazy_import.lazy_module('tarfile')
lazy_import.lazy_module('threading')
lazy_import.lazy_module('json')
lazy_import.lazy_module('bravado.exception')
lazy_import.lazy_module('bravado.requests_client')
lazy_import.lazy_module('bravado.client')
lazy_import.lazy_module('urllib.parse')
lazy_import.lazy_module('keycloak')
lazy_import.lazy_module('time')
lazy_import.lazy_module('matplotlib.scale')
lazy_import.lazy_module('matplotlib.pyplot')
lazy_import.lazy_module('matplotlib.ticker')
lazy_import.lazy_module('matplotlib.transforms')
lazy_import.lazy_module('numpy')
lazy_import.lazy_module('nomad.config')
lazy_import.lazy_module('nomad.utils')
lazy_import.lazy_module('nomad.processing')
lazy_import.lazy_module('nomad.files')
lazy_import.lazy_module('nomad.search')
lazy_import.lazy_module('nomad.datamodel')
lazy_import.lazy_module('nomad.parsing')
lazy_import.lazy_module('nomad.parsing.parsers')
lazy_import.lazy_module('nomad.infrastructure')
lazy_import.lazy_module('nomad.doi')
lazy_import.lazy_module('nomad.client')

from . import local, upload, integrationtests, mirror, statistics, update_database  # noqa
from .client import create_client  # noqa
from .upload import stream_upload_with_client  # noqa



# Copyright 2015-2018 Massimo Riello, Adam Fekete, Fawzi Mohamed, Ankit Kariryaa
# 
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

from LAMMPS.BaseClasses import Neighbor

# Default
#
# 0.3 bin for units = lj, skin = 0.3 sigma
# 2.0 bin for units = real or metal, skin = 2.0 Angstroms
# 0.001 bin for units = si, skin = 0.001 meters = 1.0 mm
# 0.1 bin for units = cgs, skin = 0.1 cm = 1.0 mm


class Bin(Neighbor):
    name = 'bin'
    pass


class Nsq(Neighbor):
    name = 'nsq'
    pass


class Multi(Neighbor):
    name = 'multi'
    pass




# Copyright 2015-2018 Massimo Riello, Adam Fekete, Fawzi Mohamed, Ankit Kariryaa
# 
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""
This is the access point to the parser for the scala layer in the
nomad project.
"""
from __future__ import absolute_import
import sys
import setup_paths

from LammpsParser import LammpsParser
from nomadcore.parser_backend import JsonParseEventsWriterBackend


if __name__ == "__main__":

    # Initialise the parser with the main filename and a JSON backend
    main_file = sys.argv[1]
    parser = LammpsParser(main_file, backend=JsonParseEventsWriterBackend)
    parser.parse()



import numpy as np            # pylint: disable=unused-import
import typing                 # pylint: disable=unused-import
from nomad.metainfo import (  # pylint: disable=unused-import
    MSection, MCategory, Category, Package, Quantity, Section, SubSection, SectionProxy,
    Reference
)
from nomad.metainfo.legacy import LegacyDefinition

from nomad.datamodel.metainfo import public

m_package = Package(
    name='asap_nomadmetainfo_json',
    description='None',
    a_legacy=LegacyDefinition(name='asap.nomadmetainfo.json'))


class section_sampling_method(public.section_sampling_method):

    m_def = Section(validate=False, extends_base_section=True, a_legacy=LegacyDefinition(name='section_sampling_method'))

    x_asap_langevin_friction = Quantity(
        type=np.dtype(np.float64),
        shape=[],
        description='''
        Friction coeffient used in Langevin dynamics
        ''',
        a_legacy=LegacyDefinition(name='x_asap_langevin_friction'))

    x_asap_maxstep = Quantity(
        type=np.dtype(np.float64),
        shape=[],
        description='''
        Maxstep in Angstrom for geometry optimization
        ''',
        a_legacy=LegacyDefinition(name='x_asap_maxstep'))

    x_asap_temperature = Quantity(
        type=np.dtype(np.float64),
        shape=[],
        description='''
        Temperature used in molecular-dynamics
        ''',
        a_legacy=LegacyDefinition(name='x_asap_temperature'))

    x_asap_timestep = Quantity(
        type=np.dtype(np.float64),
        shape=[],
        description='''
        Timestep in molecular dynamics
        ''',
        a_legacy=LegacyDefinition(name='x_asap_timestep'))


m_package.__init_metainfo__()
